@@ -1,7 +1,5 @@
 package Benchmark::Perl::Formance::Plugin::RxMicro;
-BEGIN {
-  $Benchmark::Perl::Formance::Plugin::RxMicro::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: benchmark plugin - Rx - Stress regular expressions
 
 # Regexes
@@ -145,7 +143,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
